@@ -23,8 +23,7 @@
 #include <glib/gi18n.h>
 #include <string.h>
 #include <glib.h>
-#include <gnome.h>
-#include <libgnomevfs/gnome-vfs.h>
+#include <libgnomeui/libgnomeui.h>
 #include <gconf/gconf-client.h>
 #include "gui.h"
 #include "navigation-tree.h"
@@ -117,6 +116,8 @@ fe_args (int argc, char *argv[])
 		return 0;
 	}
 
+	g_set_application_name (_("IRC Chat"));
+
 	if (opt_cfgdir) {
 		xdir_fs = opt_cfgdir;
 	}
@@ -137,17 +138,17 @@ fe_init (void)
 
 	u = userlist_new ();
 	gui.quit = FALSE;
-	servlist_init ();
 	palette_init ();
 	run_migrations ();
+	initialize_gui_1 ();
 	if (!preferences_exist ()) {
 		run_setup_dialog ();
 	} else {
 		set_version ();
 	}
-	load_preferences ();
-	initialize_gui_1 ();
+	servlist_init ();
 	initialize_gui_2 ();
+	load_preferences ();
 	run_main_window ();
 
 	/* Force various window-related options to match our interaction model */
@@ -412,6 +413,10 @@ fe_close_window (struct session *sess)
 		status_bar_remove_server (STATUS_BAR (gui.status_bar), sess->server);
 	}
 
+	if (sess == gui.current_session) {
+		gui.current_session = NULL;
+	}
+
 	session_free (sess);
 }
 
@@ -428,9 +433,15 @@ fe_progressbar_end (struct server *serv)
 }
 
 void
-fe_print_text (struct session *sess, char *text)
+fe_print_text (struct session *sess, char *text, time_t stamp)
 {
-	conversation_panel_print (CONVERSATION_PANEL (gui.conversation_panel), sess, text, prefs.indent_nicks);
+	if (text == NULL) {
+		g_warning ("NULL passed to fe_print_text.  Perhaps a misbehaving plugin?\n");
+		return;
+	}
+
+	conversation_panel_print (CONVERSATION_PANEL (gui.conversation_panel),
+	                          sess, text, prefs.indent_nicks);
 	sess->new_data = TRUE;
 	navigation_model_set_hilight (gui.tree_model, sess);
 	if (sess->nick_said) {
@@ -802,14 +813,15 @@ get_str_response (GtkDialog * dialog, gint arg1, gpointer entry)
 	switch (arg1) {
 	case GTK_RESPONSE_REJECT:
 		callback (TRUE, text, user_data);
-		gtk_widget_destroy (GTK_WIDGET (dialog));
 		break;
 	case GTK_RESPONSE_ACCEPT:
 		callback (FALSE, text, user_data);
-		gtk_widget_destroy (GTK_WIDGET (dialog));
 		break;
 	}
+
+	gtk_widget_destroy (GTK_WIDGET (dialog));
 }
+
 static void
 str_enter (GtkWidget * entry, GtkWidget * dialog)
 {
@@ -861,13 +873,13 @@ get_number_response (GtkDialog * dialog, gint arg1, gpointer spin)
 	switch (arg1) {
 	case GTK_RESPONSE_REJECT:
 		callback (TRUE, num, user_data);
-		gtk_widget_destroy (GTK_WIDGET (dialog));
 		break;
 	case GTK_RESPONSE_ACCEPT:
 		callback (FALSE, num, user_data);
-		gtk_widget_destroy (GTK_WIDGET (dialog));
 		break;
 	}
+
+	gtk_widget_destroy (GTK_WIDGET (dialog));
 }
 
 void
@@ -915,10 +927,10 @@ fe_open_url (const char *url)
 	screen = gtk_widget_get_screen (gui.main_window);
 	if (strstr (url, "://") == NULL) {
 		gchar *newword = g_strdup_printf ("http://%s", url);
-		gnome_url_show_on_screen (newword, screen, &err);
+		gtk_show_uri (screen, newword, gtk_get_current_event_time (), &err);
 		g_free (newword);
 	} else {
-		gnome_url_show_on_screen (url, screen, &err);
+		gtk_show_uri (screen, url, gtk_get_current_event_time (), &err);
 	}
 
 	if (err != NULL) {
@@ -1127,6 +1139,6 @@ fe_set_current (session *sess)
 /* Tray stubs -- xchat-gnome bundles this as a plugin */
 void fe_tray_set_flash (const char *filename1, const char *filename2, int timeout) {}
 void fe_tray_set_file (const char *filename) {}
-void fe_tray_set_icon (int icon) {}
+void fe_tray_set_icon (feicon icon) {}
 void fe_tray_set_tooltip (const char *text) {}
 void fe_tray_set_balloon (const char *title, const char *text) {}
