@@ -1,7 +1,7 @@
 /*
  * find-bar.c - Widget encapsulating the find bar
  *
- * Copyright (C) 2004-2006 xchat-gnome team
+ * Copyright (C) 2004-2007 xchat-gnome team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -81,24 +81,16 @@ find_bar_class_init (FindBarClass *klass)
 static void
 find_bar_init (FindBar *bar)
 {
-	GtkWidget *close;
-	GtkWidget *close_image;
-	GtkWidget *find_label;
-	GtkWidget *previous;
-	GtkWidget *previous_image;
-	GtkWidget *next;
-	GtkWidget *next_image;
-
 	bar->priv = g_new0 (FindBarPriv, 1);
 
-	close            = gtk_button_new ();
-	close_image      = gtk_image_new_from_stock (GTK_STOCK_CLOSE, GTK_ICON_SIZE_BUTTON);
-	find_label       = gtk_label_new (_("Find:"));
+	GtkWidget *close            = gtk_button_new ();
+	GtkWidget *close_image      = gtk_image_new_from_stock (GTK_STOCK_CLOSE, GTK_ICON_SIZE_BUTTON);
+	GtkWidget *find_label       = gtk_label_new (_("Find:"));
+	GtkWidget *previous         = gtk_button_new_with_mnemonic (_("_Previous"));
+	GtkWidget *previous_image   = gtk_image_new_from_stock (GTK_STOCK_GO_BACK, GTK_ICON_SIZE_BUTTON);
+	GtkWidget *next             = gtk_button_new_with_mnemonic (_("_Next"));
+	GtkWidget *next_image       = gtk_image_new_from_stock (GTK_STOCK_GO_FORWARD, GTK_ICON_SIZE_BUTTON);
 	bar->priv->entry = gtk_entry_new ();
-	previous         = gtk_button_new_with_mnemonic (_("_Previous"));
-	previous_image   = gtk_image_new_from_stock (GTK_STOCK_GO_BACK, GTK_ICON_SIZE_BUTTON);
-	next             = gtk_button_new_with_mnemonic (_("_Next"));
-	next_image       = gtk_image_new_from_stock (GTK_STOCK_GO_FORWARD, GTK_ICON_SIZE_BUTTON);
 
 	bar->priv->status_wrapped = gtk_image_new_from_icon_name ("xchat-gnome-search-wrapped", GTK_ICON_SIZE_MENU);
 	bar->priv->status_notfound = gtk_image_new_from_stock (GTK_STOCK_DIALOG_WARNING, GTK_ICON_SIZE_BUTTON);
@@ -142,9 +134,7 @@ find_bar_init (FindBar *bar)
 static void
 find_bar_finalize (GObject *object)
 {
-	FindBar *bar;
-
-	bar = FIND_BAR (object);
+	FindBar *bar = FIND_BAR (object);
 
 	g_free (bar->priv);
 
@@ -186,11 +176,10 @@ find_bar_search (FindBar *bar, gboolean reverse)
 	position = conversation_panel_search (CONVERSATION_PANEL (gui.conversation_panel), text, bar->priv->last_position, FALSE, reverse);
 
 	if ((position == NULL) && (bar->priv->last_position != NULL)) {
+		position = conversation_panel_search (CONVERSATION_PANEL (gui.conversation_panel), text, NULL, FALSE, reverse);
 		if (reverse) {
-			position = conversation_panel_search (CONVERSATION_PANEL (gui.conversation_panel), text, NULL, FALSE, reverse);
 			find_bar_set_status (bar, STATUS_WRAPPED_REVERSE);
 		} else {
-			position = conversation_panel_search (CONVERSATION_PANEL (gui.conversation_panel), text, NULL, FALSE, reverse);
 			find_bar_set_status (bar, STATUS_WRAPPED);
 		}
 	} else if (position == NULL) {
